# _Trimesh_ 

In this directory you will find a bunch of examples of interoperability with the 
[trimesh](https://trimsh.org) package. 

(Still a bit experimental, especially when running from a jupyter notebook. Use in this case _embedWindow(False)_).

To run the examples:
```bash
git clone https://github.com/marcomusy/vedo.git
cd vedo/vedo/examples/other/trimesh
python example.py
```
(_click thumbnail image to get to the python script_)

|    |    |
|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|:-----|
| [![trim_section](https://user-images.githubusercontent.com/32848391/60594020-55220100-9da4-11e9-8d7f-281965616795.png)](https://github.com/marcomusy/vedo/blob/master/vedo/examples/other/trimesh/section.py)<br/>`section.py`      | Find a bunch of parallel cross sections to a mesh. |
|    |    |
| [![trim_ray](https://user-images.githubusercontent.com/32848391/60594021-55220100-9da4-11e9-87be-f2004f1060df.png)](https://github.com/marcomusy/vedo/blob/master/vedo/examples/other/trimesh/ray.py)<br/>`ray.py`                | Find hits of a ray to mesh. |
|    |    |
| [![trim_nearest](https://user-images.githubusercontent.com/32848391/60594022-55220100-9da4-11e9-82ba-19f38af63d35.png)](https://github.com/marcomusy/vedo/blob/master/vedo/examples/other/trimesh/nearest.py)<br/>`nearest.py`    | Find the closest points on a mesh to a set of random point. |
|    |    |
| [![trim_shortest](https://user-images.githubusercontent.com/32848391/60594023-55220100-9da4-11e9-87b4-73ea7f8b04f7.png)](https://github.com/marcomusy/vedo/blob/master/vedo/examples/other/trimesh/shortest.py)<br/>`shortest.py`      | Shortest path query using length for edge weight. |

